/*
 * $Id: rx_inflate.h,v 1.4 2003/01/01 00:14:36 cbiere Exp $
 *
 * Copyright (c) 2002, Raphael Manfredi
 *
 * Network RX -- multiplexed decompressing stage.
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

#ifndef _rx_inflate_h_
#define _rx_inflate_h_

#include "rx.h"

struct rxdrv_ops rx_inflate_ops;

#endif	/* _rx_inflate_h_ */

/* vi: set ts=4: */

